aboutsummaryrefslogtreecommitdiff
path: root/src/crepe/system/InputSystem.h
diff options
context:
space:
mode:
authorWBoerenkamps <wrj.boerenkamps@student.avans.nl>2024-12-09 15:29:18 +0100
committerWBoerenkamps <wrj.boerenkamps@student.avans.nl>2024-12-09 15:29:18 +0100
commita80477f2e7f4c18adcc6441828d17582aad2598f (patch)
treefc26007bf3c9ea463cb4572bc26cf176d4b85d63 /src/crepe/system/InputSystem.h
parent2ff3369a7aaf98936bf93f1c7c0dbfcaa38c31d7 (diff)
get_keyboard_state working
Diffstat (limited to 'src/crepe/system/InputSystem.h')
-rw-r--r--src/crepe/system/InputSystem.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/crepe/system/InputSystem.h b/src/crepe/system/InputSystem.h
index 87e86f8..1d6e79c 100644
--- a/src/crepe/system/InputSystem.h
+++ b/src/crepe/system/InputSystem.h
@@ -3,6 +3,7 @@
#include "../facade/SDLContext.h"
#include "../types.h"
#include "../util/OptionalRef.h"
+#include "../api/Config.h"
#include "System.h"
@@ -37,8 +38,8 @@ private:
//! Stores the last mouse button pressed.
MouseButton last_mouse_button = MouseButton::NONE;
- //! The maximum allowable distance between mouse down and mouse up to register as a click.
- const int click_tolerance = 5;
+ //! The maximum allowable distance between mouse down and mouse up to register as a click. This can be changed using the Config.
+ int click_tolerance = Config::get_instance().click_tolerance.tolerance;
/**
* \brief Handles the mouse click event.